@@ -1,4 +1,4 @@
-from src.ansidocs.classes.static.config import Config
+from ansidocs.classes.static.config import Config
 
 
 class UknownLayoutException(Exception):
